@@ -16,7 +16,13 @@ class JSSourceDarkTheme(SourceBase):
     css_filename = 'themes/default-dark/style.css'
 
 
+class JSSourceDarkProtonTheme(SourceBase):
+    static_path = 'cards/jstree/'
+    css_filename = 'themes/proton/style.css'
+
+
 packages = {
     'jstree_default': [JSSourceTree, JSSourceDefaultTheme],
+    'jstree_proton': [JSSourceTree, JSSourceDarkProtonTheme],
     'jstree_dark': [JSSourceTree, JSSourceDarkTheme],
 }
